@@ -116,8 +116,9 @@ market_codes = [
 
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get stock codes.')
 @click.option('-m', '--market', 'markets', metavar='MARKET', multiple=True, type=click.Choice(market_codes, case_sensitive=False), help='Stock market code to get. Can set multiple times.')
+@click.option('-n', '--name', metavar='NAME', help='Name of stock.')
 @click.option('-p', '--port', metavar='PORT', help='Port number of grpc server (optional).')
-def stockcode(markets, port):
+def stockcode(markets, name, port):
     """
     \b
     Possible market codes are:
@@ -137,17 +138,20 @@ def stockcode(markets, port):
       all: All possible market codes.
     """
 
-    if (markets) == (tuple()):
+    if (markets, name) == (tuple(), None):
         fail_with_usage()
 
     from koapy import KiwoomOpenApiContext
 
-    if 'all' in markets:
-        markets = market_codes
-
     with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout) as context:
         context.EnsureConnected()
 
+        if name is not None and not markets:
+            markets = ['0']
+
+        if 'all' in markets:
+            markets = market_codes
+
         codes = set()
 
         for market in markets:
@@ -155,8 +159,17 @@ def stockcode(markets, port):
 
         codes = sorted(list(codes))
 
-        for code in codes:
-            click.echo(code)
+        if not name:
+            for code in codes:
+                click.echo(code)
+        else:
+            names = [context.GetMasterCodeName(code) for code in codes]
+            codes_by_name = dict(zip(names, codes))
+            code = codes_by_name.get(name, None)
+            if code:
+                click.echo(code)
+            else:
+                click.echo('Cannot find code for given name.')
 
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get name for stock codes.')
 @click.option('-c', '--code', 'codes', metavar='CODE', multiple=True, help='Stock code to get. Can set multiple times.')
@@ -546,21 +559,22 @@ def trinfo(trcodes):
                     break
 
     for trcode in get_codes():
-        if not trcode.startswith('opt'):
-            trcode = 'opt' + trcode
         trinfo = TrInfo.get_trinfo_by_code(trcode)
-        click.echo('[%s] : [%s]' % (trinfo.tr_code.upper(), trinfo.name))
-        click.echo('  [INPUT]')
-        for input in trinfo.inputs:
-            click.echo('    %s' % input.name)
-        if trinfo.single_outputs:
-            click.echo('  [OUTPUT] [SINGLE DATA] : [%s]' % trinfo.single_outputs_name)
-            for output in trinfo.single_outputs:
-                click.echo('    %s' % output.name)
-        if trinfo.multi_outputs:
-            click.echo('  [OUTPUT] [MULTI DATA]  : [%s]' % trinfo.multi_outputs_name)
-            for output in trinfo.multi_outputs:
-                click.echo('    %s' % output.name)
+        if trinfo is not None:
+            click.echo('[%s] : [%s]' % (trinfo.tr_code.upper(), trinfo.name))
+            click.echo('  [INPUT]')
+            for input in trinfo.inputs:
+                click.echo('    %s' % input.name)
+            if trinfo.single_outputs:
+                click.echo('  [OUTPUT] [SINGLE DATA] : [%s]' % trinfo.single_outputs_name)
+                for output in trinfo.single_outputs:
+                    click.echo('    %s' % output.name)
+            if trinfo.multi_outputs:
+                click.echo('  [OUTPUT] [MULTI DATA]  : [%s]' % trinfo.multi_outputs_name)
+                for output in trinfo.multi_outputs:
+                    click.echo('    %s' % output.name)
+        else:
+            click.echo('Given trcode is invalid')
 
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get real type info.')
 @click.option('-t', '--realtype', 'realtypes', metavar='REALTYPE', multiple=True, help='Real type name to get (like 주식시세).')
@@ -594,6 +608,8 @@ def realinfo(realtypes):
             names = [RealType.Fid.get_name_by_fid(fid, str(fid)) for fid in fids]
             for fid, name in zip(fids, names):
                 click.echo('  [%s] = %s' % (fid, name))
+        else:
+            click.echo('Given realtype is invalid')
 
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get market holidays.')
 @click.option('-o', '--output', metavar='FILENAME', type=click.Path(), help='Output filename. (optional)')
@@ -609,14 +625,9 @@ def holidays(output, offline, update, no_update, verbose):
         if not offline:
             from koapy.utils.krx.marketdata.holiday import download_holidays_as_dict
             response = download_holidays_as_dict()
-            if not no_update:
-                from koapy.utils.krx.holiday.KrxBusinessDay import dump_holidays
-                dump_holidays(response)
         else:
-            from koapy.utils.krx.holiday import get_holidays_as_dict
+            from koapy.utils.krx.calendar import get_holidays_as_dict
             response = get_holidays_as_dict()
-            if not no_update or update:
-                logging.warning('Cannot update while offline.')
         lang = locale.getdefaultlocale()[0]
         if lang == 'ko_KR':
             day_key = 'kr_dy_tp'
@@ -870,9 +881,9 @@ def watch(codes, input, fids, realtype, output, format, port, verbose):
     from koapy.openapi.RealType import RealType
 
     def parse_message(message):
-        fids = event.listen_response.single_data.names
+        fids = event.single_data.names
         names = [RealType.Fid.get_name_by_fid(fid, str(fid)) for fid in fids]
-        values = event.listen_response.single_data.values
+        values = event.single_data.values
         dic = dict((name, value) for fid, name, value in zip(fids, names, values) if name != fid)
         series = pd.Series(dic)
         return series
@@ -882,8 +893,8 @@ def watch(codes, input, fids, realtype, output, format, port, verbose):
             click.echo(parse_message(message).to_json(), file=output)
     else:
         def print_message(message):
-            code = event.listen_response.arguments[0].string_value
-            name = event.listen_response.arguments[1].string_value
+            code = event.arguments[0].string_value
+            name = event.arguments[1].string_value
             click.echo('[%s] [%s]' % (code, name), file=output)
             click.echo('[%s]' % datetime.datetime.now(), file=output)
             click.echo(parse_message(message).to_markdown(), file=output)
