@@ -6,8 +6,7 @@ class KiwoomOpenApiDynamicCallable:
         'SetInputValue',
         'DisconnectRealData',
         'SetRealRemove',
-        'SetCondition',
-        'SetConditionStop',
+        'SendConditionStop',
     ]
 
     def __init__(self, control, name):
@@ -34,7 +33,6 @@ class KiwoomOpenApiDynamicCallable:
         if kwargs:
             logging.warning('Ignoring given kwargs..')
         function = self._createDynamicCallFunction(self._name, args)
-        # logging.debug('Calling dynamicCall(%r, %r)', function, args)
         if len(args) > 0:
             # giving args as tuple raises an error, ex) _.dynamicCall('...', args)
             # giving unpacked args has length limitation, ex) _.dynamicCall('...', *args)
@@ -44,7 +42,6 @@ class KiwoomOpenApiDynamicCallable:
         # 파라미터 개수가 틀리거나 타입이 틀리거나 같은 경우에 에러체킹이 안됨
         # 뾰족한 방법이 없어보여서 아래처럼 구현
         if result is None and self._name not in self._void_method_names:
-            logging.error('Non-void method returned None.')
             raise ValueError('Non-void method returned None.')
         return result
 
